urlify

package module
v0.0.0-...-5315183 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 11, 2021 License: MIT Imports: 6 Imported by: 0

README

urlify

Proxy-like Service which sends Push Notifications

Environment

Variable Description
URL The URL of the data to respond
ALLOWED_REQUESTER The IP of the system which is allowed to get the data
TOKEN The Pushover token
USER The Pushover user

Prerequisites

To use this service you need the following two prerequisites.

Google Cloud Platform account

This code can be used with a GCP Cloud Function.

For that you need an account at GCP.

Pushover Notifications account

This code needs an account at Pushover Notifications,

to send the notifications to your clients.

Related Article

To get more information regarding the purpose of this code, please see my article on Medium

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Handle

func Handle(w http.ResponseWriter, r *http.Request)

Handle will handle the cloud function call

Types

This section is empty.

Jump to